@@ -310,30 +310,23 @@ app_load_css (GApplication *application)
   add_css_provider (application, TRUE);
 }
 
-void
+char *
 terminal_app_new_profile (TerminalApp *app,
-                          GSettings   *base_profile)
+                          GSettings   *base_profile,
+                          const char  *name)
 {
-  gs_unref_object GSettings *profile = NULL;
-  gs_free char *uuid;
+  char *uuid;
 
   if (base_profile) {
     gs_free char *base_uuid;
 
     base_uuid = terminal_settings_list_dup_uuid_from_child (app->profiles_list, base_profile);
-    uuid = terminal_settings_list_clone_child (app->profiles_list, base_uuid);
+    uuid = terminal_settings_list_clone_child (app->profiles_list, base_uuid, name);
   } else {
-    uuid = terminal_settings_list_add_child (app->profiles_list);
+    uuid = terminal_settings_list_add_child (app->profiles_list, name);
   }
 
-  if (uuid == NULL)
-    return;
-
-  profile = terminal_settings_list_ref_child (app->profiles_list, uuid);
-  if (profile == NULL)
-    return;
-
-  terminal_profile_edit (profile, "profile-name-entry");
+  return uuid;
 }
 
 void
@@ -625,7 +618,7 @@ app_menu_preferences_cb (GSimpleAction *action,
 {
   TerminalApp *app = user_data;
 
-  terminal_app_edit_preferences (app);
+  terminal_app_edit_preferences (app, NULL, NULL);
 }
 
 static void
@@ -696,13 +689,30 @@ terminal_app_startup (GApplication *application)
 
   app_load_css (application);
 
+  /* Figure out whether the shell shows appmenu/menubar */
+  gboolean shell_shows_appmenu, shell_shows_menubar;
+  g_object_get (gtk_settings_get_default (),
+                "gtk-shell-shows-app-menu", &shell_shows_appmenu,
+                "gtk-shell-shows-menubar", &shell_shows_menubar,
+                NULL);
+
   /* App menu */
   GMenu *appmenu_new_terminal_section = gtk_application_get_menu_by_id (gtk_application,
                                                                         "new-terminal-section");
   fill_new_terminal_section (appmenu_new_terminal_section, NULL, 0); /* no submenu */
 
   /* Menubar */
-  terminal_util_load_objects_resource ("/org/gnome/terminal/ui/menubar.ui",
+  /* If the menubar is shown by the shell, omit mnemonics for the submenus. This is because Alt+F etc.
+   * are more important to be usable in the terminal, the menu cannot be replaced runtime (to toggle
+   * between mnemonic and non-mnemonic versions), gtk-enable-mnemonics or gtk_window_set_mnemonic_modifier()
+   * don't effect the menubar either, so there wouldn't be a way to disable Alt+F for File etc. otherwise.
+   * Furthermore, the menu would even grab mnemonics from the File and Preferences windows.
+   * In Unity, Alt+F10 opens the menubar, this should be good enough for keyboard navigation.
+   * If the menubar is shown by the app, toggling mnemonics is handled in terminal-window.c using
+   * gtk_window_set_mnemonic_modifier().
+   * See bug 792978 for details. */
+  terminal_util_load_objects_resource (shell_shows_menubar ? "/org/gnome/terminal/ui/menubar-without-mnemonics.ui"
+                                                           : "/org/gnome/terminal/ui/menubar-with-mnemonics.ui",
                                        "menubar", &app->menubar,
                                        "new-terminal-section", &app->menubar_new_terminal_section,
                                        "set-profile-section", &app->menubar_set_profile_section,
@@ -717,13 +727,10 @@ terminal_app_startup (GApplication *application)
   /* Install the encodings submenu */
   terminal_encodings_append_menu (app->menubar_set_encoding_submenu);
 
-  /* If the shell wants to show the appmenu/menubar, make it available */
-  gboolean shell_shows_appmenu, shell_shows_menubar;
-  g_object_get (gtk_settings_get_default (),
-                "gtk-shell-shows-app-menu", &shell_shows_appmenu,
-                "gtk-shell-shows-menubar", &shell_shows_menubar,
-                NULL);
-  if (!shell_shows_appmenu)
+  /* Show/hide the appmenu/menubar as appropriate:
+   * If the shell wants to show the menubar, make it available.
+   * If the shell wants to show both the appmenu and the menubar, there's no need for the appmenu. */
+  if (shell_shows_appmenu && shell_shows_menubar)
     gtk_application_set_app_menu (GTK_APPLICATION (app), NULL);
   if (shell_shows_menubar)
     gtk_application_set_menubar (GTK_APPLICATION (app), app->menubar);
@@ -1093,17 +1100,11 @@ terminal_app_get_clipboard_targets (TerminalApp *app,
 }
 
 void
-terminal_app_edit_profile (TerminalApp     *app,
-                           GSettings       *profile,
-                           const char      *widget_name)
+terminal_app_edit_preferences (TerminalApp     *app,
+                               GSettings       *profile,
+                               const char      *widget_name)
 {
-  terminal_profile_edit (profile, widget_name);
-}
-
-void
-terminal_app_edit_preferences (TerminalApp *app)
-{
-  terminal_prefs_show_preferences ("general");
+  terminal_prefs_show_preferences (profile, widget_name);
 }
 
 /**
